spacepy.seapy.sea_signif — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- SeaPy - Superposed Epoch in Python »

# spacepy.seapy.sea_signif

`spacepy.seapy.` `sea_signif`(obj1, obj2, test='KS', show=True, xquan='Time Since Epoch', yquan='', xunits='', yunits='', epochline=True, usrlimy=[])

  Test for similarity between distributions at each lag in two 1-D SEAs

  Parameters: | Two seapy.Sea() instances for comparison :
  Other Parameters:
  | - show (default = True) : x(y)quan (default = ‘Time since epoch’ (None)) - x(y)-axis label. x(y)units (default = None (None)) - x(y)-axis units. epochline (default = True) - put vertical line at zero epoch. usrlimy (default = []) - override automatic y-limits on plot.

  Examples

      >>> obj1 = seapy.Sea(data1, times1, epochs1)
      >>> obj2 = seapy.Sea(data2, times2, epochs2)
      >>> obj1.sea(storedata=True)
      >>> obj2.sea(storedata=True)
      >>> seapy.sea_signif(obj1, obj2)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- SeaPy - Superposed Epoch in Python »